@@ -39,11 +39,101 @@ __all__ = [
 ]
 
 
+def _parse_config(config_input: Config | dict[str, Any] | str | None) -> Config:
+    """Parse config from various formats.
+
+    Args:
+        config_input: Can be:
+            - Config object: returned as-is
+            - dict: converted to Config
+            - str: parsed as JSON string or treated as file path
+            - None: loads default config
+
+    Returns:
+        Config: Parsed configuration object
+
+    Raises:
+        TypeError: If config_input type is not supported
+    """
+    if config_input is None:
+        return load_config()
+
+    if isinstance(config_input, Config):
+        return config_input
+
+    if isinstance(config_input, str):
+        try:
+            config_dict = json.loads(config_input)
+            return Config(**config_dict)
+        except json.JSONDecodeError:
+            # Assume it's a file path
+            return load_config(config_input)
+
+    if isinstance(config_input, dict):
+        return Config(**config_input)
+
+    raise TypeError(f"Unsupported config type: {type(config_input)}")
+
+
+def _parse_file_shadow(shadow_input: dict[str, str] | str | None) -> dict[str, str] | None:
+    """Parse file shadow from dict or JSON string.
+
+    Args:
+        shadow_input: Can be:
+            - dict: mapping from file patterns to license expressions
+            - str: JSON string to be parsed
+            - None: no shadow rules
+
+    Returns:
+        dict or None: Parsed shadow patterns
+
+    Example:
+        >>> _parse_file_shadow('{"//kernel/*": "Apache-2.0"}')
+        {'//kernel/*': 'Apache-2.0'}
+    """
+    if shadow_input is None:
+        return None
+
+    if isinstance(shadow_input, str):
+        return json.loads(shadow_input)
+
+    return shadow_input
+
+
+def _parse_license_shadow(shadow_input: dict[str, list[str]] | str | None) -> dict[str, list[str]]:
+    """Parse license shadow from dict or JSON string.
+
+    License shadow allows ignoring specific license incompatibilities.
+
+    Args:
+        shadow_input: Can be:
+            - dict: mapping from license to list of licenses to ignore conflicts with
+            - str: JSON string to be parsed
+            - None: no shadow rules
+
+    Returns:
+        dict: Parsed shadow rules (empty dict if None)
+
+    Example:
+        >>> _parse_license_shadow('{"GPL-3.0": ["MIT", "Apache-2.0"]}')
+        {'GPL-3.0': ['MIT', 'Apache-2.0']}
+    """
+    if shadow_input is None:
+        return {}
+
+    if isinstance(shadow_input, str):
+        return json.loads(shadow_input)
+
+    return shadow_input
+
+
 def check_compatibility(
     license_map: Mapping[str, str],
     graph_input: GraphManager | str | dict[str, Any],
     *,
-    config: Config | None = None,
+    config: Config | dict[str, Any] | str | None = None,
+    file_shadow: dict[str, str] | str | None = None,
+    license_shadow: dict[str, list[str]] | str | None = None,
     args: ParserInitArgs = None,
 ) -> tuple[GraphManager, dict[str, dict]]:
     """Execute the canonical Scancode → Exception → Decycle → Propagate → Compatibility pipeline.
@@ -51,13 +141,41 @@ def check_compatibility(
     Args:
         license_map: Mapping from graph node labels ("//path") to SPDX expressions.
         graph_input: Existing graph context, a JSON payload, or a path that resolves to a graph export.
-        config: Optional pre-loaded configuration; defaults to :func:`load_config`.
+        config: Optional configuration. Can be:
+            - Config object: used as-is
+            - dict: converted to Config
+            - str: parsed as JSON string or treated as file path
+            - None: loads default config
+        file_shadow: Optional file-to-license shadow mappings. Can be:
+            - dict: mapping from file patterns to license expressions
+            - str: JSON string to be parsed
+            - None: no shadow rules
+            Example: {"//kernel/*": "Apache-2.0", "//specific/file.c": "MIT"}
+        license_shadow: Optional license incompatibility shadow rules. Can be:
+            - dict: mapping from license to list of licenses to ignore conflicts with
+            - str: JSON string to be parsed
+            - None: no shadow rules
+            Example: {"GPL-3.0": ["MIT", "Apache-2.0"]} - ignores GPL-3.0/MIT and GPL-3.0/Apache-2.0 conflicts
         args: Unified argument set shared across all parser stages.
 
     Returns:
         tuple: A tuple containing:
             - GraphManager: The graph after compatibility evaluation.
             - dict: The results dictionary containing conflict information.
+
+    Example:
+        >>> from liscopelens.api import check_compatibility
+        >>> license_map = {"//src/main.c": "GPL-3.0", "//lib/helper.c": "MIT"}
+        >>> graph_input = {"nodes": [...], "edges": [...]}
+        >>> context, results = check_compatibility(license_map, graph_input)
+
+        >>> # With file shadow
+        >>> file_shadow = {"//kernel/*": "Apache-2.0"}
+        >>> context, results = check_compatibility(license_map, graph_input, file_shadow=file_shadow)
+
+        >>> # With license shadow to ignore certain conflicts
+        >>> license_shadow = {"GPL-3.0": ["MIT"]}
+        >>> context, results = check_compatibility(license_map, graph_input, license_shadow=license_shadow)
     """
 
     if not isinstance(license_map, Mapping):
@@ -65,11 +183,20 @@ def check_compatibility(
             "license_map must be a mapping of node labels to SPDX expressions"
         )
 
-    resolved_config = config or load_config()
+    # Parse inputs
+    resolved_config = _parse_config(config)
+    resolved_file_shadow = _parse_file_shadow(file_shadow)
+    resolved_license_shadow = _parse_license_shadow(license_shadow)
+
+    print(resolved_config)
 
     scancode_parser = ScancodeParser(args, resolved_config)
     context = scancode_parser(dict(license_map), graph_input)
 
+    # Apply file shadow if provided
+    if resolved_file_shadow:
+        scancode_parser._apply_shadow_licenses(context, resolved_file_shadow)
+
     exception_parser = BaseExceptionParser(args, resolved_config)
     context = exception_parser(context)
 
@@ -80,6 +207,8 @@ def check_compatibility(
     context = propagate_parser(context)
 
     compatible_parser = BaseCompatiblityParser(args, resolved_config)
+    # Set license shadow on the parser
+    compatible_parser.license_shadow = resolved_license_shadow
     context, results = compatible_parser(context)
 
     return context, results
