@@ -49,6 +49,7 @@ class BaseCompatiblityParser(BaseParser):
         super().__init__(args, config)
         self.checker = Checker()
         self._global_conflicts_table: dict[str, set[frozenset[str]]] = {}
+        self.license_shadow: dict[str, list[str]] = {}  # New: license shadow rules
 
     def parse_condition(self, condition: str) -> Optional[str]:
         """
@@ -62,6 +63,37 @@ class BaseCompatiblityParser(BaseParser):
         """
         return self.config.literal2enum(condition)
 
+    def _is_conflict_shadowed(self, license_a: str, license_b: str) -> bool:
+        """Check if a conflict between two licenses is shadowed (should be ignored).
+
+        A conflict is shadowed if either license_a lists license_b in its shadow rules,
+        or vice versa.
+
+        Args:
+            license_a: First license SPDX ID
+            license_b: Second license SPDX ID
+
+        Returns:
+            bool: True if the conflict should be ignored, False otherwise
+
+        Example:
+            >>> parser.license_shadow = {"GPL-3.0": ["MIT", "Apache-2.0"]}
+            >>> parser._is_conflict_shadowed("GPL-3.0", "MIT")
+            True
+            >>> parser._is_conflict_shadowed("MIT", "GPL-3.0")
+            True
+            >>> parser._is_conflict_shadowed("GPL-3.0", "BSD-3-Clause")
+            False
+        """
+        if not self.license_shadow:
+            return False
+
+        # Check both directions
+        return (
+            (license_a in self.license_shadow and license_b in self.license_shadow[license_a]) or
+            (license_b in self.license_shadow and license_a in self.license_shadow[license_b])
+        )
+
     def topological_traversal(self, graph: nx.DiGraph) -> Generator[str, None, None]:
         """Topological sort the graph."""
         return nx.topological_sort(graph)
@@ -206,6 +238,9 @@ class BaseCompatiblityParser(BaseParser):
                     condition_type
                 )
                 if result == CompatibleType.INCOMPATIBLE:
+                    # Check if this conflict is shadowed
+                    if self._is_conflict_shadowed(license_a.unit_spdx, license_b.unit_spdx):
+                        continue  # Skip this conflict - it's shadowed
                     conflicts.add(frozenset((license_a.unit_spdx, license_b.unit_spdx)))
                     group_rm_flag = True
 
