@@ -704,11 +704,17 @@ class GraphManager:
 
     def create_vertex(self, label: str, **kwargs: Any) -> Vertex:
         """Create a vertex"""
-        return Vertex(label, parser_name=self.__class__.__name__, **kwargs)
+        # Avoid passing duplicate parser_name if provided by caller
+        if "parser_name" not in kwargs:
+            kwargs["parser_name"] = self.__class__.__name__
+        return Vertex(label, **kwargs)
 
     def create_edge(self, u: str, v: str, **kwargs: Any) -> Edge:
         """Create an edge between two vertices"""
-        return Edge(u, v, parser_name=self.__class__.__name__, **kwargs)
+        # Avoid passing duplicate parser_name if provided by caller
+        if "parser_name" not in kwargs:
+            kwargs["parser_name"] = self.__class__.__name__
+        return Edge(u, v, **kwargs)
 
     def export_for_web(self) -> dict[str, str]:
         """
